@@ -23,6 +23,8 @@
 
 import re
 
+import fpyutils
+
 
 # _ctoi and _isascii taken from cpython source Lib/curses/ascii.py
 # See:
@@ -47,8 +49,124 @@ def _isascii(c):
     return 0 <= _ctoi(c) <= 127
 
 
-def _replace_substring(source: str, replacement: str, start: int, end: int) -> str:
-    r"""Given a string called source, replace it with a string called replacement between the start ~ end interval."""
+def _extract_lines(input_file: str, start: int, end: int) -> str:
+    r"""Extract lines from file between start and end line numbers, with line numbers starting from 1."""
+    if start > end or start < 1 or end < 1:
+        raise ValueError
+
+    lines: list = list()
+    line_counter: int = 1
+
+    with open(input_file, 'r') as f:
+        line = f.readline()
+        while line:
+            if line_counter >= start and line_counter <= end:
+                lines.append(line)
+            line = f.readline()
+            line_counter += 1
+
+    return ''.join(lines)
+
+
+def _remove_line_intervals(filename: str, line_intervals: list):
+    # A nested list of integers divided in couples is expected.
+    # Example: [[1, 4], [8, 9]]
+    for interval in line_intervals:
+        if len(interval) != 2 or interval[0] < 1 or interval[
+                1] < 1 or interval[0] > interval[1]:
+            raise ValueError
+
+        fpyutils.filelines.remove_line_interval(
+            filename,
+            interval[0],
+            interval[1],
+            filename,
+        )
+
+
+def _get_existing_toc(filename: str, marker: str) -> tuple:
+    r"""Get the existing TOC in a file and return other important data about the TOC and its markers."""
+    # TOC marker positions.
+    marker_line_positions, lines = fpyutils.filelines.get_line_matches(
+        filename,
+        marker,
+        0,
+        loose_matching=True,
+        keep_all_lines=True,
+    )
+    marker_line_positions_length: int = len(marker_line_positions)
+
+    old_toc: str = str()
+    first_marker: int = 1
+    second_marker: int = 2
+    two_or_more_markers: bool = False
+    done: bool = False
+    first_marker_line_number: int = 0
+    lines_to_delete: list = list()
+
+    if marker_line_positions_length > 0:
+        first_marker_line_number = marker_line_positions[first_marker]
+
+    # Possible pre-existing TOC.
+    while not done and marker_line_positions_length >= 2:
+
+        interval: str = _read_line_interval(
+            lines, marker_line_positions[first_marker] + 1,
+            marker_line_positions[second_marker] - 1)
+
+        # Line intervals excluding the newline after the first <!--TOC-->
+        # and before the last <!--TOC-->.
+        interval_with_newline: str = _read_line_interval(
+            lines, marker_line_positions[first_marker] + 2,
+            marker_line_positions[second_marker] - 2)
+
+        # TODO: add code fence detection.
+        if _detect_toc_list(interval_with_newline) or _string_empty(interval):
+
+            # Skip the opening and closing TOC markers.
+            start_line: int = marker_line_positions[first_marker] + 1
+            end_line: int = marker_line_positions[second_marker] - 1
+
+            if start_line <= end_line:
+                # Real TOC detected.
+                old_toc = _extract_lines(filename, start_line,
+                                         end_line).strip()
+            else:
+                old_toc = str()
+
+            lines_to_delete.append([
+                marker_line_positions[first_marker],
+                marker_line_positions[second_marker]
+            ])
+
+            first_marker_line_number = marker_line_positions[first_marker]
+            done = True
+
+        first_marker += 1
+        second_marker += 1
+        marker_line_positions_length -= 1
+        two_or_more_markers = True
+
+    # Only 1 pre-existing marker. TOC is just the marker.
+    if not two_or_more_markers and marker_line_positions_length == 1:
+        old_toc = marker
+
+    return old_toc, lines_to_delete, two_or_more_markers, marker_line_positions_length, marker_line_positions, first_marker_line_number
+
+
+def _replace_substring(source: str, replacement: str, start: int,
+                       end: int) -> str:
+    r"""Given a string called source, replace it with a string called replacement between the start and end indices interval."""
+    # Avoid possibility to pass lists to this function which the program would
+    # happily process.
+    if not isinstance(source, str):
+        raise TypeError
+    if not isinstance(replacement, str):
+        raise TypeError
+
+    if start > end:
+        raise ValueError
+
     replaced: list = list()
     replaced_str: str
     was_replaced: bool = False
@@ -58,6 +176,7 @@ def _replace_substring(source: str, replacement: str, start: int, end: int) -> s
         if i < start or i > end:
             replaced.append(source[i])
         elif not was_replaced:
+            # Only one replacement is possible.
             replaced.append(replacement)
             was_replaced = True
         i += 1
@@ -66,8 +185,8 @@ def _replace_substring(source: str, replacement: str, start: int, end: int) -> s
     return replaced_str
 
 
-# A weaker version of C's strncmp: this one does not count the characters
-# it just notify if there are differences.
+# A weaker version of C's strncmp: this one does not count the characters,
+# it just notifies if there are differences.
 def _strncmp(s1: str, s2: str, length: int) -> int:
     i: int = 0
     retval: int = 0
@@ -190,7 +309,9 @@ def _utf8_array_to_string(array: list) -> str:
 def _string_empty(lines: str) -> bool:
     empty: bool = True
     # Avoid matching \n\r
-    if re.fullmatch('((?!\u000a\u000d)|(?!\u000a\u000d)\u000d\u000a|(?!\u000a\u000d)\u000d|(?!\u000a\u000d)\u000a|(?!\u000a\u000d)\u000b|(?!\u000a\u000d)\u0020|(?!\u000a\u000d)\u0009)+', lines) is None:
+    if re.fullmatch(
+            '((?!\u000a\u000d)|(?!\u000a\u000d)\u000d\u000a|(?!\u000a\u000d)\u000d|(?!\u000a\u000d)\u000a|(?!\u000a\u000d)\u000b|(?!\u000a\u000d)\u0020|(?!\u000a\u000d)\u0009)+',
+            lines) is None:
         empty = False
 
     return empty
@@ -198,8 +319,17 @@ def _string_empty(lines: str) -> bool:
 
 def _detect_toc_list(line: str) -> bool:
     # An heuristic to detect a TOC list generated by md-toc.
+    # If a user deletes the first TOC list line by mistake
+    # there might be additional spaces (max 3 possible)
+    # at the start of the second line
+    # See
+    # https://spec.commonmark.org/0.30/#example-288
+    # and
+    # https://spec.commonmark.org/0.30/#example-289
     match = True
-    if re.fullmatch(r'([-+*]|' + r'\d' + '+[.' + r'\)' + '])\u0020((?![\u0020\u0009\u000b]+).*)', line) is None:
+    if re.fullmatch(
+            r' {0,3}([-+*]|' + r'\d' + '+[.' + r'\)' +
+            '])\u0020((?![\u0020\u0009\u000b]+).*)', line) is None:
         match = False
 
     return match
@@ -226,17 +356,20 @@ def _read_line_interval(lines: str, start: int, end: int) -> str:
         invalid_newline: bool = False
 
         # Skip \n\r
-        while i + 1 < lines_length and lines[i] == '\u000a' and lines[i + 1] == '\u000d':
+        while i + 1 < lines_length and lines[i] == '\u000a' and lines[
+                i + 1] == '\u000d':
             i += 2
             invalid_newline = True
 
         # Get \r\n as a single newline character.
-        while i + 1 < lines_length and lines[i] == '\u000d' and lines[i + 1] == '\u000a':
+        while i + 1 < lines_length and lines[i] == '\u000d' and lines[
+                i + 1] == '\u000a':
             line_counter += 1
             i += 2
 
         # Get \r or \n
-        while i < lines_length and re.fullmatch('[\u000d\u000a]', lines[i]) is not None:
+        while i < lines_length and re.fullmatch('[\u000d\u000a]',
+                                                lines[i]) is not None:
             line_counter += 1
             i += 1
 
